@@ -18,11 +18,11 @@ cxxfunction.copy <- function( cppfct , name ){
 crlrem <- function( filename1 , filename2 ){
     filename <- filename1
     con <- file(filename, "rb")
-    bin <- readBin(con, raw(), 100000)
+    bin <- base::readBin(con, raw(), 100000)
     bin <- bin[ which(bin != "0d") ]
     close(con)
     Sys.sleep(1)
     con <- file(filename2, "wb")
-    writeBin(bin, con)
+    base::writeBin(bin, con)
     close(con)
         }
\ No newline at end of file
