@@ -5,8 +5,8 @@ mice.impute.2l.eap <- function (y, ry, x,  eap , ...){
     newstate <- get( "newstate" , pos = parent.frame() )  
     M.scale <- eap[[ vname ]][[ "M" ]]
     SE.scale <- eap[[ vname ]][[ "SE" ]]
-    ximp <- rnorm( length(M.scale) , mean= M.scale , sd = SE.scale )
-	flush.console()
+    ximp <- stats::rnorm( length(M.scale) , mean= M.scale , sd = SE.scale )
+	utils::flush.console()
     # return imputed values	
     return(ximp)	
 }
