@@ -158,11 +158,11 @@ mice.impute.2l.pls <- function(y, ry, x , type , pls.facs = NULL ,
 						
 						# eliminate correlations
 						if ( ! use.ymat ){ 
-								c1 <- cor( y[ry] , hx[ry,] ) 
+								c1 <- stats::cor( y[ry] , hx[ry,] ) 
 								}
 									else {  
 											# look for correlations of all the dummy variables
-											c1 <- cor( y[ry,] , hx[ry,] ) 
+											c1 <- stats::cor( y[ry,] , hx[ry,] ) 
 											c1 <- apply( abs(c1) , 2 , mean , na.rm=T )
 											}
 						c1[ is.na(c1) ] <- 0
@@ -224,11 +224,11 @@ mice.impute.2l.pls <- function(y, ry, x , type , pls.facs = NULL ,
 		#---------------
 		# look for minimal absolute correlations for all variables
 			# eliminate correlations
-			if ( ! use.ymat ){ c1 <- cor( y[ry] , x[ry,] ) }
+			if ( ! use.ymat ){ c1 <- stats::cor( y[ry] , x[ry,] ) }
 									else {  
 											# look for correlations of all the dummy variables
-											c1 <- cor( y[ry,] , x[ry,] ) 
-											c1 <- apply( abs(c1) , 2 , mean , na.rm=T )
+											c1 <- stats::cor( y[ry,] , x[ry,] ) 
+											c1 <- apply( abs(c1) , 2 , mean , na.rm=TRUE )
 											}
             elim.ind <- which( abs(c1) < min.all.cor )
 			N11 <- ncol(x)		
@@ -249,10 +249,10 @@ mice.impute.2l.pls <- function(y, ry, x , type , pls.facs = NULL ,
 									}
 		# look for largest correlations
 			if ( ! use.ymat ){ 
-					c1 <- cor( y[ry] , x[ry,] ) 
+					c1 <- stats::cor( y[ry] , x[ry,] ) 
 							}	else {  
 											# look for correlations of all the dummy variables
-											c1 <- cor( y[ry,] , x[ry,] ) 
+											c1 <- stats::cor( y[ry,] , x[ry,] ) 
 											c1 <- apply( abs(c1) , 2 , mean , na.rm=T )
 											}
 			if ( ( N.largest < 1 ) & ( N12 > 100 ) ){ 
@@ -267,7 +267,7 @@ mice.impute.2l.pls <- function(y, ry, x , type , pls.facs = NULL ,
 			x <- x[ , dfr1[ 1:N.largest , "index" ] ]
 			# look if some columns do have complete missing entries or SD of zero
 			cmna1 <- which( colMeans( is.na(x))  == 1 )
-			cmna2 <- which( apply( x , 2, sd ) == 0 )
+			cmna2 <- which( apply( x , 2, stats::sd ) == 0 )
 			cmna <- unique( sort( c( cmna1 , cmna2 ) ) )
 
 			if ( length(cmna) > 0 ){ 
@@ -328,7 +328,7 @@ mice.impute.2l.pls <- function(y, ry, x , type , pls.facs = NULL ,
         # include imputationWeights here and calculate weight.obs
         # in the regression model, only PLS factors of X are used
 		
-        if( sd(weight.obs) > 0){
+        if( stats::sd(weight.obs) > 0){
                 yobs <- weight.obs * yobs
                 xobs <- outer( weight.obs , rep(1,ncol(xobs) ) ) * xobs
                                 }
