@@ -17,8 +17,8 @@
     residuals <- yobs - xobs %*% coef
 	df_r <- sum(ry) - ncol(x)
 	df_r <- max( df_r , 2 )
-    sigma.star <- sqrt(sum((residuals)^2)/rchisq(1, df_r ))
-    beta.star <- coef + (t(chol((v + t(v))/2)) %*% rnorm(ncol(x))) * 
+    sigma.star <- sqrt(sum((residuals)^2)/ stats::rchisq(1, df_r ))
+    beta.star <- coef + (t(chol((v + t(v))/2)) %*% stats::rnorm(ncol(x))) * 
         sigma.star
     parm <- list(coef, beta.star, sigma.star)
     names(parm) <- c("coef", "beta", "sigma")
