@@ -11,9 +11,9 @@ summary.mipo.nmi <- function(object, digits=3 ,  ...) {
     table[, 3] <- table[, 1]/table[, 2]
     table[, 4] <- x$df
     table[, 5] <- if (all(x$df > 0)) 
-        2 * (1 - pt(abs(table[, 3]), x$df)) else NA
-    table[, 6] <- table[, 1] - qt(0.975, x$df) * table[, 2]
-    table[, 7] <- table[, 1] + qt(0.975, x$df) * table[, 2]
+        2 * (1 - stats::pt(abs(table[, 3]), x$df)) else NA
+    table[, 6] <- table[, 1] - stats::qt(0.975, x$df) * table[, 2]
+    table[, 7] <- table[, 1] + stats::qt(0.975, x$df) * table[, 2]
 #    if (is.null(x$nmis) | is.null(names(x$qbar)))
 #        table[, 8] <- NA else table[, 8] <- x$nmis[names(x$qbar)]
     table[, "fmi"] <- x$lambda
